document.addEventListener('DOMContentLoaded', () => {
  const textarea = document.getElementById('base64Input');
  const outputImage = document.getElementById('outputImage');
  let debounceTimer;

  const updateImage = (base64String) => {
    try {
      // Check if the string starts with data:image
      if (!base64String.startsWith('data:image')) {
        // Try to add the prefix if it's missing
        base64String = 'data:image/png;base64,' + base64String.replace(/^data:image\/(png|jpeg|jpg|gif);base64,/, '');
      }
      
      outputImage.src = base64String;
      
      // Handle load errors
      outputImage.onerror = () => {
        outputImage.src = 'data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7';
        console.error('Invalid image data');
      };
    } catch (error) {
      console.error('Error updating image:', error);
    }
  };

  // Add input event listener with debounce
  textarea.addEventListener('input', (e) => {
    clearTimeout(debounceTimer);
    debounceTimer = setTimeout(() => {
      updateImage(e.target.value.trim());
    }, 300);
  });

  // Add paste event listener
  textarea.addEventListener('paste', (e) => {
    clearTimeout(debounceTimer);
    debounceTimer = setTimeout(() => {
      updateImage(e.target.value.trim());
    }, 100);
  });
});